@@ -18,8 +18,6 @@ def create(name, profile):
     try:
         pg = project_generator.ProjectGenerator(
             project_name=name,
-            aws_profile=credentials["aws_profile"],
-            aws_region="us-east-1",
             client_id=credentials["client_id"],
             client_secret=credentials["client_secret"],
             profile=profile,
