@@ -1,7 +1,5 @@
 import base64
 import json
-import sys
-import importlib
 
 from pathlib import Path
 from requests.exceptions import HTTPError
@@ -14,8 +12,7 @@ from slai_cli import constants
 from slai_cli.errors import handle_error
 from slai_cli.create.local_config_helper import LocalConfigHelper
 
-from slai.modules.requirements import generate_requirements_from_runtime
-from slai.clients.model import ModelClient
+from slai.clients.model import get_model_client
 from slai.clients.project import get_project_client
 
 
@@ -154,7 +151,7 @@ def deploy_model(*, model_name, version):
     project_name = project_client.get_project_name()
 
     docker_client = DockerClient(project_name)
-    model_client = ModelClient(model_name=model_name, project_name=project_name)
+    model_client = get_model_client(model_name=model_name, project_name=project_name)
 
     local_config_helper = LocalConfigHelper()
     local_model_config = local_config_helper.get_local_model_config(
